@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2009 Canonical Services Ltd (www.canonical.com)
+ * Copyright (C) 2010 Canonical Services Ltd (www.canonical.com)
  *
  * Authors: Rodrigo Moya <rodrigo.moya@canonical.com>
  *
@@ -22,66 +22,87 @@
 #ifndef __COUCHDB_DOCUMENT_CONTACT_H__
 #define __COUCHDB_DOCUMENT_CONTACT_H__
 
-#include <glib.h>
-#include "couchdb-document.h"
-#include "couchdb-struct-field.h"
+#include <couchdb-struct-field.h>
+#include <couchdb-document.h>
 
 G_BEGIN_DECLS
 
-#define COUCHDB_RECORD_TYPE_CONTACT "http://www.freedesktop.org/wiki/Specifications/desktopcouch/contact"
+#define COUCHDB_TYPE_DOCUMENT_CONTACT                (couchdb_document_contact_get_type ())
+#define COUCHDB_DOCUMENT_CONTACT(obj)                (G_TYPE_CHECK_INSTANCE_CAST ((obj), COUCHDB_TYPE_DOCUMENT_CONTACT, CouchdbDocumentContact))
+#define COUCHDB_IS_DOCUMENT_CONTACT(obj)             (G_TYPE_CHECK_INSTANCE_TYPE ((obj), COUCHDB_TYPE_DOCUMENT_CONTACT))
+#define COUCHDB_DOCUMENT_CONTACT_CLASS(klass)        (G_TYPE_CHECK_CLASS_CAST ((klass), COUCHDB_TYPE_DOCUMENT_CONTACT, CouchdbDocumentContactClass))
+#define COUCHDB_IS_DOCUMENT_CONTACT_CLASS(klass)     (G_TYPE_CHECK_CLASS_TYPE ((klass), COUCHDB_TYPE_DOCUMENT_CONTACT))
+#define COUCHDB_DOCUMENT_CONTACTGET_CLASS(obj)      (G_TYPE_INSTANCE_GET_CLASS ((obj), COUCHDB_TYPE_DOCUMENT_CONTACT, CouchdbDocumentContactClass))
 
-CouchdbDocument *couchdb_document_contact_new (CouchdbSession *couchdb);
-gboolean         couchdb_document_is_contact (CouchdbDocument *document);
+typedef struct {
+	CouchdbDocument parent;
+} CouchdbDocumentContact;
+
+typedef struct {
+	CouchdbDocumentClass parent_class;
+} CouchdbDocumentContactClass;
+
+GType       couchdb_document_contact_get_type (void);
+
+CouchdbDocumentContact *couchdb_document_contact_new (void);
 
 /*
  * Top level functions to manipulate documents representing a contact
  */
 
-const char *couchdb_document_contact_get_first_name (CouchdbDocument *document);
-void        couchdb_document_contact_set_first_name (CouchdbDocument *document, const char *first_name);
-const char *couchdb_document_contact_get_last_name (CouchdbDocument *document);
-void        couchdb_document_contact_set_last_name (CouchdbDocument *document, const char *last_name);
-const char *couchdb_document_contact_get_nick_name (CouchdbDocument *document);
-void        couchdb_document_contact_set_nick_name (CouchdbDocument *document, const char *nick_name);
-const char *couchdb_document_contact_get_spouse_name (CouchdbDocument *document);
-void        couchdb_document_contact_set_spouse_name (CouchdbDocument *document, const char *spouse_name);
-const char *couchdb_document_contact_get_birth_date (CouchdbDocument *document);
-void        couchdb_document_contact_set_birth_date (CouchdbDocument *document, const char *birth_date);
-const char *couchdb_document_contact_get_wedding_date (CouchdbDocument *document);
-void        couchdb_document_contact_set_wedding_date (CouchdbDocument *document, const char *wedding_date);
+const char *couchdb_document_contact_get_title (CouchdbDocumentContact *document);
+void        couchdb_document_contact_set_title (CouchdbDocumentContact *document, const char *title);
+const char *couchdb_document_contact_get_first_name (CouchdbDocumentContact *document);
+void        couchdb_document_contact_set_first_name (CouchdbDocumentContact *document, const char *first_name);
+const char *couchdb_document_contact_get_middle_name (CouchdbDocumentContact *document);
+void        couchdb_document_contact_set_middle_name (CouchdbDocumentContact *document, const char *middle_name);
+const char *couchdb_document_contact_get_last_name (CouchdbDocumentContact *document);
+void        couchdb_document_contact_set_last_name (CouchdbDocumentContact *document, const char *last_name);
+const char *couchdb_document_contact_get_suffix (CouchdbDocumentContact *document);
+void        couchdb_document_contact_set_suffix (CouchdbDocumentContact *document, const char *suffix);
 
-const char *couchdb_document_contact_get_company (CouchdbDocument *document);
-void        couchdb_document_contact_set_company (CouchdbDocument *document, const char *company);
-const char *couchdb_document_contact_get_department (CouchdbDocument *document);
-void        couchdb_document_contact_set_department (CouchdbDocument *document, const char *department);
-const char *couchdb_document_contact_get_title (CouchdbDocument *document);
-void        couchdb_document_contact_set_title (CouchdbDocument *document, const char *title);
-const char *couchdb_document_contact_get_job_title (CouchdbDocument *document);
-void        couchdb_document_contact_set_job_title (CouchdbDocument *document, const char *job_title);
-const char *couchdb_document_contact_get_manager_name (CouchdbDocument *document);
-void        couchdb_document_contact_set_manager_name (CouchdbDocument *document, const char *manager_name);
-const char *couchdb_document_contact_get_assistant_name (CouchdbDocument *document);
-void        couchdb_document_contact_set_assistant_name (CouchdbDocument *document, const char *assistant_name);
-const char *couchdb_document_contact_get_office (CouchdbDocument *document);
-void        couchdb_document_contact_set_office (CouchdbDocument *document, const char *office);
+const char *couchdb_document_contact_get_nick_name (CouchdbDocumentContact *document);
+void        couchdb_document_contact_set_nick_name (CouchdbDocumentContact *document, const char *nick_name);
+const char *couchdb_document_contact_get_spouse_name (CouchdbDocumentContact *document);
+void        couchdb_document_contact_set_spouse_name (CouchdbDocumentContact *document, const char *spouse_name);
+const char *couchdb_document_contact_get_birth_date (CouchdbDocumentContact *document);
+void        couchdb_document_contact_set_birth_date (CouchdbDocumentContact *document, const char *birth_date);
+const char *couchdb_document_contact_get_wedding_date (CouchdbDocumentContact *document);
+void        couchdb_document_contact_set_wedding_date (CouchdbDocumentContact *document, const char *wedding_date);
 
-GSList     *couchdb_document_contact_get_email_addresses (CouchdbDocument *document);
-void        couchdb_document_contact_set_email_addresses (CouchdbDocument *document, GSList *list);
+const char *couchdb_document_contact_get_company (CouchdbDocumentContact *document);
+void        couchdb_document_contact_set_company (CouchdbDocumentContact *document, const char *company);
+const char *couchdb_document_contact_get_department (CouchdbDocumentContact *document);
+void        couchdb_document_contact_set_department (CouchdbDocumentContact *document, const char *department);
+const char *couchdb_document_contact_get_job_title (CouchdbDocumentContact *document);
+void        couchdb_document_contact_set_job_title (CouchdbDocumentContact *document, const char *job_title);
+const char *couchdb_document_contact_get_manager_name (CouchdbDocumentContact *document);
+void        couchdb_document_contact_set_manager_name (CouchdbDocumentContact *document, const char *manager_name);
+const char *couchdb_document_contact_get_assistant_name (CouchdbDocumentContact *document);
+void        couchdb_document_contact_set_assistant_name (CouchdbDocumentContact *document, const char *assistant_name);
+const char *couchdb_document_contact_get_office (CouchdbDocumentContact *document);
+void        couchdb_document_contact_set_office (CouchdbDocumentContact *document, const char *office);
 
-GSList     *couchdb_document_contact_get_phone_numbers (CouchdbDocument *document);
-void        couchdb_document_contact_set_phone_numbers (CouchdbDocument *document, GSList *list);
+GSList     *couchdb_document_contact_get_email_addresses (CouchdbDocumentContact *document);
+void        couchdb_document_contact_set_email_addresses (CouchdbDocumentContact *document, GSList *list);
 
-GSList     *couchdb_document_contact_get_addresses (CouchdbDocument *document);
-void        couchdb_document_contact_set_addresses (CouchdbDocument *document, GSList *list);
+GSList     *couchdb_document_contact_get_phone_numbers (CouchdbDocumentContact *document);
+void        couchdb_document_contact_set_phone_numbers (CouchdbDocumentContact *document, GSList *list);
 
-GSList     *couchdb_document_contact_get_im_addresses (CouchdbDocument *document);
-void        couchdb_document_contact_set_im_addresses (CouchdbDocument *document, GSList *list);
+GSList     *couchdb_document_contact_get_addresses (CouchdbDocumentContact *document);
+void        couchdb_document_contact_set_addresses (CouchdbDocumentContact *document, GSList *list);
 
-GSList     *couchdb_document_contact_get_urls (CouchdbDocument *document);
-void        couchdb_document_contact_set_urls (CouchdbDocument *document, GSList *list);
+GSList     *couchdb_document_contact_get_im_addresses (CouchdbDocumentContact *document);
+void        couchdb_document_contact_set_im_addresses (CouchdbDocumentContact *document, GSList *list);
 
-const char *couchdb_document_contact_get_notes (CouchdbDocument *document);
-void        couchdb_document_contact_set_notes (CouchdbDocument *document, const char *notes);
+GSList     *couchdb_document_contact_get_urls (CouchdbDocumentContact *document);
+void        couchdb_document_contact_set_urls (CouchdbDocumentContact *document, GSList *list);
+
+const char *couchdb_document_contact_get_categories (CouchdbDocumentContact *document);
+void        couchdb_document_contact_set_categories (CouchdbDocumentContact *document, const char *categories);
+
+const char *couchdb_document_contact_get_notes (CouchdbDocumentContact *document);
+void        couchdb_document_contact_set_notes (CouchdbDocumentContact *document, const char *notes);
 
 /*
  * Utility functions to manipulate email addresses fields
@@ -131,15 +152,18 @@ void                couchdb_document_contact_phone_set_description (CouchdbStruc
  * Utility functions to manipulate addresses
  */
 CouchdbStructField *couchdb_document_contact_address_new (const char *uuid,
-							  const char *street,
-							  const char *city,
-							  const char *state,
-							  const char *country,
-							  const char *postalcode,
-							  const char *pobox,
-							  const char *description);
+							       const char *street,
+							       const char *ext_street,
+							       const char *city,
+							       const char *state,
+							       const char *country,
+							       const char *postalcode,
+							       const char *pobox,
+							       const char *description);
 const char         *couchdb_document_contact_address_get_street (CouchdbStructField *sf);
 void                couchdb_document_contact_address_set_street (CouchdbStructField *sf, const char *street);
+const char         *couchdb_document_contact_address_get_ext_street (CouchdbStructField *sf);
+void                couchdb_document_contact_address_set_ext_street (CouchdbStructField *sf, const char *ext_street);
 const char         *couchdb_document_contact_address_get_city (CouchdbStructField *sf);
 void                couchdb_document_contact_address_set_city (CouchdbStructField *sf, const char *city);
 const char         *couchdb_document_contact_address_get_state (CouchdbStructField *sf);
