@@ -292,7 +292,7 @@ main (int argc, char *argv[])
 
 	/* Initialize data needed for all tests */
 	couchdb =  argc > 1 ? couchdb_session_new (argv[1]) : couchdb_session_new ("http://test:test@127.0.0.1:5985");
-	g_printf ("Connecting to Couchdb at %s\n", couchdb_session_get_uri (couchdb));
+	g_print ("Connecting to Couchdb at %s\n", couchdb_session_get_uri (couchdb));
 	
 	if (!couchdb) {
 		g_print ("Could not create Couchdb object\n");
